:mod:`euphorie.content.risk`
============================

Classes
-------

.. automodule:: euphorie.content.risk
   :members: Risk, SearchableTextIndexer, ConstructionFilter


Interfaces
----------

.. autointerface:: IRisk
   :members:

.. autointerface:: IFrenchEvaluation
   :members:

.. autointerface:: IKinneyEvaluation
   :members:

.. autointerface:: IKinneyRisk
   :members:

.. autointerface:: IFrenchRisk
   :members:


Views
-----

.. autoclass:: View
   :members:

.. autoclass:: Add
   :members:

.. autoclass:: Edit
   :members:





